==> v1.3.4+60.tar.gz: fapp/lib/widgets/video_widget.dart <==
import 'dart:async';

import 'package:flutter/material.dart';

import 'package:get/get.dart';
import 'package:cached_video_player_plus/cached_video_player_plus.dart';
import 'package:cached_network_image/cached_network_image.dart';

import 'package:f0ckapp/controller/media_controller.dart';
import 'package:f0ckapp/models/media_item.dart';
import 'package:f0ckapp/widgets/videooverlay_widget.dart';

class VideoWidget extends StatefulWidget {
  final MediaItem details;
  final bool isActive;
  final bool fullScreen;

  const VideoWidget({
    super.key,
    required this.details,
    required this.isActive,
    this.fullScreen = false,
  });

  @override
  State<VideoWidget> createState() => _VideoWidgetState();
}

class _VideoWidgetState extends State<VideoWidget> {
  final MediaController controller = Get.find<MediaController>();
  late CachedVideoPlayerPlusController _controller;
  bool _showControls = false;
  Timer? _hideControlsTimer;

  @override
  void initState() {
    super.initState();
    _initController();
  }

  Future<void> _initController() async {
    _controller = CachedVideoPlayerPlusController.networkUrl(
      Uri.parse(widget.details.mediaUrl),
    );
    await _controller.initialize();
    setState(() {});

    _controller.addListener(() => setState(() {}));

    if (widget.isActive) {
      _controller.play();
    }
    _controller.setLooping(true);

    _controller.setVolume(controller.muted.value ? 0.0 : 1.0);
  }

  @override
  void didUpdateWidget(covariant VideoWidget oldWidget) {
    super.didUpdateWidget(oldWidget);
    if (widget.isActive != oldWidget.isActive) {
      if (widget.isActive) {
        _controller.play();
      } else {
        _controller.pause();
      }
    }
  }

  @override
  void dispose() {
    _controller.dispose();
    _hideControlsTimer?.cancel();
    super.dispose();
  }

  void _onTap({bool ctrlButton = false}) {
    if (!ctrlButton) {
      setState(() => _showControls = !_showControls);
    }
    if (_showControls) {
      _hideControlsTimer?.cancel();
      _hideControlsTimer = Timer(const Duration(seconds: 2), () {
        setState(() => _showControls = false);
      });
    }
  }

  @override
  Widget build(BuildContext context) {
    final bool muted = controller.muted.value;
    if (_controller.value.isInitialized &&
        _controller.value.volume != (muted ? 0.0 : 1.0)) {
      _controller.setVolume(muted ? 0.0 : 1.0);
    }

    bool isAudio = widget.details.mime.startsWith('audio');

    if (widget.fullScreen) {
      return Stack(
        children: [
          Center(
            child: AspectRatio(
              aspectRatio: _controller.value.isInitialized
                  ? _controller.value.aspectRatio
                  : 9 / 16,
              child: GestureDetector(
                onTap: _onTap,
                child: isAudio
                    ? CachedNetworkImage(
                        imageUrl: widget.details.coverUrl,
                        fit: BoxFit.cover,
                        placeholder: (context, url) =>
                            const CircularProgressIndicator(),
                        errorWidget: (context, url, error) => Image.asset(
                          'assets/images/music.webp',
                          fit: BoxFit.contain,
                          width: double.infinity,
                        ),
                      )
                    : _controller.value.isInitialized
                    ? CachedVideoPlayerPlus(_controller)
                    : const Center(child: CircularProgressIndicator()),
              ),
            ),
          ),
          if (_controller.value.isInitialized && _showControls)
            Positioned.fill(
              child: GestureDetector(
                onTap: _onTap,
                child: Container(
                  color: Colors.black.withValues(alpha: 0.5),
                  child: VideoControlsOverlay(
                    controller: _controller,
                    button: () => _onTap(ctrlButton: true),
                  ),
                ),
              ),
            ),
        ],
      );
    } else {
      return Column(
        mainAxisSize: MainAxisSize.min,
        children: [
          AspectRatio(
            aspectRatio: _controller.value.isInitialized
                ? _controller.value.aspectRatio
                : 9 / 16,
            child: Stack(
              alignment: Alignment.topCenter,
              children: [
                GestureDetector(
                  onTap: _onTap,
                  child: isAudio
                      ? CachedNetworkImage(
                          imageUrl: widget.details.coverUrl,
                          fit: BoxFit.cover,
                          placeholder: (context, url) =>
                              const CircularProgressIndicator(),
                          errorWidget: (context, url, error) => Image.asset(
                            'assets/images/music.webp',
                            fit: BoxFit.contain,
                            width: double.infinity,
                          ),
                        )
                      : _controller.value.isInitialized
                      ? CachedVideoPlayerPlus(_controller)
                      : const Center(child: CircularProgressIndicator()),
                ),
                if (_controller.value.isInitialized && _showControls) ...[
                  IgnorePointer(
                    ignoring: true,
                    child: Container(
                      color: Colors.black.withValues(alpha: 0.5),
                      width: double.infinity,
                      height: double.infinity,
                    ),
                  ),
                  VideoControlsOverlay(
                    controller: _controller,
                    button: () => _onTap(ctrlButton: true),
                  ),
                ],
              ],
            ),
          ),
        ],
      );
    }
  }
}

==> v1.4.1+62.tar.gz: fapp/lib/widgets/video_widget.dart <==
import 'dart:async';

import 'package:cached_network_image/cached_network_image.dart';
import 'package:cached_video_player_plus/cached_video_player_plus.dart';
import 'package:flutter/material.dart';

import 'package:get/get.dart';

import 'package:f0ckapp/models/item.dart';
import 'package:f0ckapp/widgets/video_controls_overlay.dart';
import 'package:f0ckapp/controller/mediacontroller.dart';

class VideoWidget extends StatefulWidget {
  final MediaItem details;
  final bool isActive;
  final bool fullScreen;
  final VoidCallback? onInitialized;

  const VideoWidget({
    super.key,
    required this.details,
    required this.isActive,
    this.fullScreen = false,
    this.onInitialized,
  });

  @override
  State<VideoWidget> createState() => _VideoWidgetState();
}

class _VideoWidgetState extends State<VideoWidget> {
  final MediaController controller = Get.find<MediaController>();
  late CachedVideoPlayerPlusController _controller;
  late Worker _muteWorker;
  bool _showControls = false;
  Timer? _hideControlsTimer;

  @override
  void initState() {
    super.initState();
    _initController();
    _muteWorker = ever(controller.muted, (bool muted) {
      if (_controller.value.isInitialized) {
        _controller.setVolume(muted ? 0.0 : 1.0);
      }
    });
  }

  Future<void> _initController() async {
    _controller = CachedVideoPlayerPlusController.networkUrl(
      Uri.parse(widget.details.mediaUrl),
    );
    await _controller.initialize();
    widget.onInitialized?.call();
    if (!mounted) return;
    setState(() {});
    _controller.addListener(() => setState(() {}));
    _controller.setLooping(true);
    _controller.setVolume(controller.muted.value ? 0.0 : 1.0);

    if (widget.isActive) {
      _controller.play();
    }
  }

  @override
  void didUpdateWidget(covariant VideoWidget oldWidget) {
    super.didUpdateWidget(oldWidget);
    if (widget.isActive != oldWidget.isActive) {
      if (widget.isActive) {
        _controller.play();
      } else {
        _controller.pause();
      }
    }
  }

  @override
  void dispose() {
    _muteWorker.dispose();
    _controller.dispose();
    _hideControlsTimer?.cancel();
    super.dispose();
  }

  void _onTap({bool ctrlButton = false}) {
    if (!ctrlButton) {
      setState(() => _showControls = !_showControls);
    }
    if (_showControls) {
      _hideControlsTimer?.cancel();
      _hideControlsTimer = Timer(const Duration(seconds: 2), () {
        setState(() => _showControls = false);
      });
    }
  }

  @override
  Widget build(BuildContext context) {
    final bool muted = controller.muted.value;
    bool isAudio = widget.details.mime.startsWith('audio');

    Widget mediaContent;
    if (isAudio) {
      mediaContent = CachedNetworkImage(
        imageUrl: widget.details.coverUrl,
        fit: BoxFit.cover,
        errorWidget: (c, e, s) => Image.asset(
          'assets/images/music.webp',
          fit: BoxFit.contain,
          width: double.infinity,
        ),
      );
    } else {
      mediaContent = _controller.value.isInitialized
          ? CachedVideoPlayerPlus(_controller)
          : const Center(child: CircularProgressIndicator());
    }

    return AspectRatio(
      aspectRatio: _controller.value.isInitialized
          ? _controller.value.aspectRatio
          : (isAudio ? 16 / 9 : 9 / 16),
      child: Stack(
        alignment: Alignment.center,
        children: [
          GestureDetector(onTap: _onTap, child: mediaContent),
          if (_controller.value.isInitialized && _showControls)
            Positioned.fill(
              child: GestureDetector(
                onTap: _onTap,
                child: Container(
                  color: Colors.black.withValues(alpha: 0.5),
                  child: VideoControlsOverlay(
                    controller: _controller,
                    onOverlayTap: () => _onTap(ctrlButton: true),
                    muted: muted,
                    onMuteToggle: () {
                      controller.toggleMuted();
                    },
                  ),
                ),
              ),
            ),
        ],
      ),
    );
  }
}
